import request from '@/utils/request'
// 提案信息-新增 sqmyInfo:info:add
export function getsqmyInfoAddFn(data) {
  return request({
    'url': '/sqmyInfo/info',
    'method': 'post',
	'data':data
  })
}
// 提案信息-列表 sqmyInfo:info:list
export function getsqmyInfoListFn(data) {
  return request({
    'url': '/sqmyInfo/info/list',
    'method': 'get',
	'data':data
  })
}
// 提案信息-详情 sqmyInfo:info:query
export function getsqmyInfoDetailFn(data) {
  return request({
    'url': '/sqmyInfo/info/'+data,
    'method': 'get',
  })
}
// 提案信息-修改 sqmyInfo:info:edit
export function getsqmyInfoEditFn(data) {
  return request({
    'url': '/sqmyInfo/info/put',
    'method': 'post',
	'data':data
  })
}
// 提案信息-删除 sqmyInfo:info:query
export function getsqmyInfoDelFn(data) {
  return request({
    'url': '/sqmyInfo/info/delete/'+data,
    'method': 'get',
  })
}
// 提案信息-类别
export function getCasetalbFn(data) {
  return request({
    'url': '/category/proposal/categoryTree',
    'method': 'get',
	'data':data
  })
}
// 提案人员 委员信息-列表不分页member:info:listNoPage
export function getInfoListFn(data) {
  return request({
    'url': '/member/info/listNoPage',
    'method': 'get',
	'data':data
  })
}
// 是否立案sqmyInfo:info:isRecord
export function getsqmyInfoisRecordFn(data) {
  return request({
    'url': '/sqmyInfo/info/isRecord',
    'method': 'post',
	'data':data
  })
}
// 提案交办sqmyInfo:info:assign
export function getsqmyInfoAssignFn(data) {
  return request({
    'url': '/sqmyInfo/info/assign',
    'method': 'post',
	'data':data
  })
}
// 单位答复sqmy:unit:reply
export function getsqmyReplyFn(data) {
  return request({
    'url': '/sqmy/unit/reply',
    'method': 'post',
	'data':data
  })
}
// 承办单位答复委员sqmyInfo:info:cbdwdfwy
export function getsqmyInfoReplywyFn(data) {
  return request({
    'url': '/sqmyInfo/info/cbdwdfwy',
    'method': 'post',
	'data':data
  })
}
// 办结审核sqmyInfo:info:assignsh
export function getsqmyInfoShFn(data) {
  return request({
    'url': '/sqmyInfo/info/assignsh',
    'method': 'post',
	'data':data
  })
}
// 委员意见sqmyInfo:info:idea
export function getsqmyInfoIdeaFn(data) {
  return request({
    'url': '/sqmyInfo/info/idea',
    'method': 'post',
	'data':data
  })
}
// 政协意见sqmyInfo:info:zxIdea
export function getsqmyInfozxIdeaFn(data) {
  return request({
    'url': '/sqmyInfo/info/zxIdea',
    'method': 'post',
	'data':data
  })
}


// 推荐重点sqmyInfo:info:keyPoint
export function getsqmyInfokeyPointFn(data) {
  return request({
    'url': '/sqmyInfo/info/keyPoint',
    'method': 'post',
	'data':data
  })
}
// 推荐优秀sqmyInfo:info:outstanding
export function getsqmyInfooutstandingFn(data) {
  return request({
    'url': '/sqmyInfo/info/outstanding',
    'method': 'post',
	'data':data
  })
}
//联名提案信息列表proposalInfo:info:jointlyList
// export function getInfojointlyListFn(data) {
//   return request({
//     'url': '/proposalInfo/info/jointlyList',
//     'method': 'get',
// 	'data':data
//   })
// }
//联名确认proposal:user:verify
// export function getUserverifyFn(data) {
//   return request({
//     'url': '/proposal/user/verify',
//     'method': 'post',
// 	'data':data
//   })
// }
//社情民意-承办单位信息列表proposalInfo:info:unitList
export function getsqmyInfounitListFn(data) {
  return request({
    'url': '/sqmyInfo/info/unitList',
    'method': 'get',
	'data':data
  })
}
//催办zxUrge:urge:add
export function getInfourgeFn(data) {
  return request({
    'url': '/zxUrge/urge',
    'method': 'post',
	'data':data
  })
}
//催办sqmyInfo:info:sqmycbList
export function getsqmyInfocbListFn(data) {
  return request({
    'url': '/sqmyInfo/info/sqmycbList',
    'method': 'get',
	'data':data
  })
}